Documentation
¶
Overview ¶
Package parse implements a parser for the Go benchmark format.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Collection ¶
Collection of results from parsing benchmark output.
type Result ¶
type Result struct {
// FullName is the complete name of the benchmark, including parameters.
FullName string
// Name of the benchmark, excluding parameters and the "Benchmark" prefix.
Name string
// Parameters of the benchmark, extracted from the name.
Parameters map[string]string
// Labels are the persistent labels that applied to the result.
Labels map[string]string
// Iterations.
Iterations uint64
// Value measured by the benchmark.
Value float64
// Unit of the measured value.
Unit string
// Line number on which the result was found.
Line int
}
Result is a benchmark result.
Click to show internal directories.
Click to hide internal directories.